#' @title The Genie Package
#'
#' @description
#' See \code{\link{hclust2}()} for details.
#'
#' @author Marek Gagolewski, Maciej Bartoszuk, Anna Cena
#'
#' @useDynLib genie, .registration=TRUE
#' @importFrom Rcpp evalCpp
"_PACKAGE"
